Installation
Author: Julien Mairal

## 2 Installation

The SPAMS toolbox for Python is distributed in source mode.

It should compile on linux and Mac. A specific python compatible version is available. We recommend to use the version of SPAMS available on PyPI (c.f. below), or the source version designed to run with the Anaconda Python, especially to benefit from the MKL Intel library.

To install from the PyPI repository, you can use the following command:
`pip install spams`

To install the version of SPAMS specifically designed for the MKL Intel library, you can do: `pip install spams_mkl`

The installation procedure is described in the file `INSTALL-package`

- Download the tar gzipped file, unpack it.
- Enter directory spams-python
- execute
  `python setup.py install --prefix=<your-installation-dir>`

You have the choice of the BLAS library, but the Intel MKL is recommended for the best performance.

If you want to add or change libraries, you must modify the file `setup.py`.

The documentation is available in pdf and html format in the `doc` subdirectory.